@@ -39,13 +39,13 @@
 #include "../VFS/virt_vfs.h"
 #include "../KViewer/krviewer.h"
 #include "../panelmanager.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqhbox.h>
 #include <tqlabel.h>
 #include <tqlayout.h>
 #include <tqfontmetrics.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <tqcursor.h>
 #include <tqeventloop.h>
 #include <kfinddialog.h>
@@ -65,10 +65,10 @@
 #define COPY_SELECTED_TO_CLIPBOARD  95
 //////////////////////////////////////////////////////////
 
-class LocateListView : public KListView
+class LocateListView : public TDEListView
 {
 public:
-  LocateListView( TQWidget * parent, const char * name = 0 ) : KListView( parent, name )
+  LocateListView( TQWidget * parent, const char * name = 0 ) : TDEListView( parent, name )
   {
   }
 
@@ -94,7 +94,7 @@ public:
   }
 };
 
-KProcess *  LocateDlg::updateProcess = 0;
+TDEProcess *  LocateDlg::updateProcess = 0;
 LocateDlg * LocateDlg::LocateDialog = 0;
 
 LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KDialogBase::User2 | KDialogBase::User3 | KDialogBase::Close,
@@ -171,7 +171,7 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   {
     if( updateProcess->isRunning() )
     {
-      connect( updateProcess, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(updateFinished()));
+      connect( updateProcess, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(updateFinished()));
       enableButton( KDialogBase::User2, false );
     }
     else
@@ -198,12 +198,12 @@ void LocateDlg::slotUser2()   /* The Update DB button */
   {
     krConfig->setGroup("Locate");
 
-    updateProcess = new KProcess();
+    updateProcess = new TDEProcess();
     *updateProcess << KrServices::fullPathName( "updatedb" );
     *updateProcess << KrServices::separateArgs( krConfig->readEntry( "UpdateDB Arguments", "" ) );
     
-    connect( updateProcess, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(updateFinished()));
-    updateProcess->start(KProcess::NotifyOnExit);
+    connect( updateProcess, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(updateFinished()));
+    updateProcess->start(TDEProcess::NotifyOnExit);
     enableButton( KDialogBase::User2, false );
   }
 }
@@ -246,11 +246,11 @@ void LocateDlg::slotUser3()   /* The locate button */
 
   stopping = false;
   
-  KProcess locateProc;
-  connect( &locateProc, TQT_SIGNAL( receivedStdout(KProcess *, char *, int) ),
-            this, TQT_SLOT( processStdout(KProcess *, char *, int) ) );
-  connect( &locateProc, TQT_SIGNAL( receivedStderr(KProcess *, char *, int) ),
-            this, TQT_SLOT( processStderr(KProcess *, char *, int) ) );
+  TDEProcess locateProc;
+  connect( &locateProc, TQT_SIGNAL( receivedStdout(TDEProcess *, char *, int) ),
+            this, TQT_SLOT( processStdout(TDEProcess *, char *, int) ) );
+  connect( &locateProc, TQT_SIGNAL( receivedStderr(TDEProcess *, char *, int) ),
+            this, TQT_SLOT( processStderr(TDEProcess *, char *, int) ) );
 
   locateProc << KrServices::fullPathName( "locate" );
   if( !isCs )
@@ -263,7 +263,7 @@ void LocateDlg::slotUser3()   /* The locate button */
     pattern = pattern + "*";
   
   collectedErr = "";
-  bool result = !locateProc.start( KProcess::Block, KProcess::AllOutput );
+  bool result = !locateProc.start( TDEProcess::Block, TDEProcess::AllOutput );
   if( !collectedErr.isEmpty() && ( !locateProc.normalExit() || locateProc.exitStatus() ) )
   {
      KMessageBox::error( krApp, i18n( "Locate produced the following error message:\n\n" ) + collectedErr );
@@ -284,7 +284,7 @@ void LocateDlg::slotUser3()   /* The locate button */
   }
 }
 
-void LocateDlg::processStdout(KProcess *proc, char *buffer, int length)
+void LocateDlg::processStdout(TDEProcess *proc, char *buffer, int length)
 {
   char *buf = new char[ length+1 ];
   memcpy( buf, buffer, length );
@@ -321,9 +321,9 @@ void LocateDlg::processStdout(KProcess *proc, char *buffer, int length)
       }
       
       if( lastItem )    
-        lastItem = new KListViewItem( resultList, lastItem, *it );
+        lastItem = new TDEListViewItem( resultList, lastItem, *it );
       else
-        lastItem = new KListViewItem( resultList, *it );
+        lastItem = new TDEListViewItem( resultList, *it );
 
       lastItem->setDragEnabled( true );
     }
@@ -335,7 +335,7 @@ void LocateDlg::processStdout(KProcess *proc, char *buffer, int length)
   tqApp->processEvents();
 }
 
-void LocateDlg::processStderr(KProcess *, char *buffer, int length)
+void LocateDlg::processStderr(TDEProcess *, char *buffer, int length)
 {
   char *buf = new char[ length+1 ];
   memcpy( buf, buffer, length );
@@ -351,7 +351,7 @@ void LocateDlg::slotRightClick(TQListViewItem *item)
     return;
 
   // create the menu
-  KPopupMenu popup;
+  TDEPopupMenu popup;
   popup.insertTitle(i18n("Locate"));
 
   popup.insertItem(i18n("View (F3)"), VIEW_ID);
@@ -479,7 +479,7 @@ void LocateDlg::operate( TQListViewItem *item, int task )
         resultList->setCurrentItem( ( findOptions & KFindDialog::FindBackwards ) ?
                                     resultList->lastItem() : resultList->firstChild() );
 
-      findCurrentItem = (KListViewItem *)resultList->currentItem();
+      findCurrentItem = (TDEListViewItem *)resultList->currentItem();
       
       if( find() && findCurrentItem )
         resultList->setCurrentItem( findCurrentItem );
@@ -495,7 +495,7 @@ void LocateDlg::operate( TQListViewItem *item, int task )
       if( task == FIND_PREV_ID )
         findOptions ^= KFindDialog::FindBackwards;
       
-      findCurrentItem = (KListViewItem *)resultList->currentItem();
+      findCurrentItem = (TDEListViewItem *)resultList->currentItem();
       nextLine();
 
       if( find() && findCurrentItem )
@@ -536,9 +536,9 @@ void LocateDlg::operate( TQListViewItem *item, int task )
 void LocateDlg::nextLine()
 {
   if( findOptions & KFindDialog::FindBackwards )
-    findCurrentItem = (KListViewItem *)findCurrentItem->itemAbove();
+    findCurrentItem = (TDEListViewItem *)findCurrentItem->itemAbove();
   else
-    findCurrentItem = (KListViewItem *)findCurrentItem->itemBelow();
+    findCurrentItem = (TDEListViewItem *)findCurrentItem->itemBelow();
 }
 
 bool LocateDlg::find()
@@ -598,7 +598,7 @@ void LocateDlg::feedToListBox()
   }
   KURL url = KURL::fromPathOrURL(TQString("virt:/")+ queryName);
   v.vfs_refresh( url );
-  v.vfs_addFiles( &urlList, KIO::CopyJob::Copy, 0 );
+  v.vfs_addFiles( &urlList, TDEIO::CopyJob::Copy, 0 );
   //ACTIVE_FUNC->openUrl(url);  
   ACTIVE_MNG->slotNewTab(url.prettyURL());
   accept();
