@@ -607,7 +607,7 @@ void Krusader::setupActions() {
                                SLOTS, TQT_SLOT( createChecksum() ), actionCollection(), "create checksum" );
    actMatchChecksum = new TDEAction( i18n( "Verify Checksum..." ), "match_checksum", 0,
                                SLOTS, TQT_SLOT( matchChecksum() ), actionCollection(), "match checksum" );
-   actProperties = new TDEAction( i18n( "&Properties..." ), 0, ALT+Key_Enter,
+   actProperties = new TDEAction( i18n( "&Properties..." ), "edit", ALT+Key_Enter,
                                 SLOTS, TQT_SLOT( properties() ), actionCollection(), "properties" );
    actPack = new TDEAction( i18n( "Pac&k..." ), "kr_arc_pack", ALT + Key_P,
                           SLOTS, TQT_SLOT( slotPack() ), actionCollection(), "pack" );
@@ -715,7 +715,7 @@ void Krusader::setupActions() {
                                   SLOTS, TQT_SLOT( customFilter() ), actionCollection(), "custom files" );
    actCompare = new TDEAction( i18n( "Compare b&y Content..." ), "application-vnd.tde.tdemultiple", 0,
                              SLOTS, TQT_SLOT( compareContent() ), actionCollection(), "compare" );
-   actMultiRename = new TDEAction( i18n( "Multi &Rename..." ), "krename", SHIFT + Key_F9,
+   actMultiRename = new TDEAction( i18n( "Multi &Rename..." ), "edit_rename", SHIFT + Key_F9,
                                  SLOTS, TQT_SLOT( multiRename() ), actionCollection(), "multirename" );
    new TDEAction( i18n( "Right-click Menu" ), Key_Menu,
                 SLOTS, TQT_SLOT( rightclickMenu() ), actionCollection(), "rightclick menu" );
